<?php
/**
 * bootBiz for Wedding functions and definitions
 *
 * @package bootBiz
 */


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function bootBiz_content_width() {
  $GLOBALS['content_width'] = apply_filters( 'bootBiz_content_width', 500 );
}
add_action( 'after_setup_theme', 'bootBiz_content_width', 0 );

/**
 * using wp_bootstrap_navwalker
 */
require get_template_directory() . '/inc/wp_bootstrap_navwalker.php';


/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';


/*
 * Sets up theme defaults and registers support for various WordPress features.
 */
if ( ! function_exists( 'bootBiz_wp_setup' ) ) :
function bootBiz_wp_setup() {
  
  load_theme_textdomain( 'bootbiz-for-wedding', get_template_directory() . '/languages' );
  add_theme_support( 'automatic-feed-links' );
  add_theme_support( 'post-thumbnails' );
  add_theme_support( 'title-tag' );
  register_nav_menu( 'mainmenu', esc_html__( 'Header Menu', 'bootbiz-for-wedding' ) );
  add_theme_support( 'custom-background', array( 'default-color' => 'ffffff') );
  add_editor_style( 'editor-style.css' );
}
endif;
add_action( 'after_setup_theme', 'bootBiz_wp_setup' );

function bootBiz_wp_scripts() {
  // CSS(header)
  wp_enqueue_style( 'bootstrap.min.css', get_stylesheet_directory_uri(). '/css/bootstrap.min.css', '', '3.3.5' );
  wp_enqueue_style( 'bootstrap-glyphicons.css', get_stylesheet_directory_uri(). '/css/bootstrap-glyphicons.css', '', '3.0.0' );
  wp_enqueue_style( 'bootBiz-basic-style', get_stylesheet_uri() );

  // JavaScript(footer)
  wp_enqueue_script( 'bootstrap.min.js', get_stylesheet_directory_uri() .'/js/bootstrap.min.js', array('jquery'), '3.2.0', true );
  wp_enqueue_script( 'jquery.matchHeight.js', get_stylesheet_directory_uri() .'/js/jquery.matchHeight.js', array('jquery'), '0.5.2', true );
  wp_enqueue_script( 'bootbiz.js', get_template_directory_uri().'/js/bootbiz.js' );

  wp_enqueue_script( 'respond.min.js', get_template_directory_uri().'/js/respond.min.js' );
  wp_script_add_data( 'respond.min.js', 'conditional', 'lt IE 9' );
  wp_enqueue_script( 'html5shiv.js',get_template_directory_uri().'/js/html5shiv.js');
  wp_script_add_data( 'html5shiv.js', 'conditional', 'lt IE 9' );

  if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
    wp_enqueue_script( 'comment-reply' );
  }
}
add_action( 'wp_enqueue_scripts', 'bootBiz_wp_scripts' );

function bootBiz_wp_widgets_setup() {
  register_sidebar( array(
        'name'          => __( 'Blog Sidebar', 'bootbiz-for-wedding' ),
        'description'   => __( 'Appears on blog page sidebar', 'bootbiz-for-wedding' ),
        'id'            => 'sidebar',
        'before_widget' => '<div class="sidebar_widget">',
        'before_title'  => '<h3>',
        'after_title'   => '</h3>',
        'after_widget'  => '</div>',
        ) );
  register_sidebar( array(
        'name'          => __( 'Site Footer', 'bootbiz-for-wedding' ),
        'description'   => __( 'Appears on all page footer', 'bootbiz-for-wedding' ),
        'id'            => 'footer',
        'before_widget' => '<div class="col-md-3 footer_widget">',
        'before_title'  => '<h3>',
        'after_title'   => '</h3>',
        'after_widget'  => '</div>',
        ) );

  // header image
  $args1 = array(
      'flex-width'    => true,
      'width'         => 1400,
      'flex-height'    => true,
      'height'        => 500,
      'default-image' => get_template_directory_uri().'/images/header1.jpg',
      'header-text-color'=>'#656464',
      'header-text' => false,
      );
  add_theme_support('custom-header',$args1);

}
add_action( 'widgets_init', 'bootBiz_wp_widgets_setup' );


/*
 * Sets up theme defaults and registers support for various WordPress features.
 * (for using bootstrap3)
 */
function bootBiz_comment_form_fields( $fields ) {
  $commenter = wp_get_current_commenter();
  
  $req      = get_option( 'require_name_email' );
  $aria_req = ( $req ? " aria-required='true'" : '' );
  $html5    = current_theme_supports( 'html5', 'comment-form' ) ? 1 : 0;
  
  $fields   =  array(
    'author' => '<div class="form-group comment-form-author">' . '<label for="author">' . __( 'Name', 'bootbiz-for-wedding' ) . ( $req ? ' <span class="required">*</span>' : '' ) . '</label> ' .
                '<input class="form-control" id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' /></div>',
    'email'  => '<div class="form-group comment-form-email"><label for="email">' . __( 'Email', 'bootbiz-for-wedding' ) . ( $req ? ' <span class="required">*</span>' : '' ) . '</label> ' .
                '<input class="form-control" id="email" name="email" ' . ( $html5 ? 'type="email"' : 'type="text"' ) . ' value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></div>',
    'url'    => '<div class="form-group comment-form-url"><label for="url">' . __( 'Website', 'bootbiz-for-wedding' ) . '</label> ' .
                '<input class="form-control" id="url" name="url" ' . ( $html5 ? 'type="url"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></div>'        
  );
  
  return $fields;
}
add_filter( 'comment_form_default_fields', 'bootBiz_comment_form_fields' );

function bootBiz_comment_form( $args ) {
    $args['comment_field'] = '<div class="form-group comment-form-comment">
            <label for="comment">' . _e( 'Comment', 'bootbiz-for-wedding' ) . '</label> 
            <textarea class="form-control" id="comment" name="comment" cols="45" rows="8" aria-required="true"></textarea>
        </div>';
    $args['class_submit'] = 'btn btn-default'; // since WP 4.1
    
    return $args;
}
add_filter( 'comment_form_defaults', 'bootBiz_comment_form' );

function bootBiz_image_class_filter($classes) {
  return $classes . ' img-responsive';
}
add_filter('get_image_tag_class', 'bootBiz_image_class_filter');

function bootBiz_calendar( $markup ) {
  $markup = str_replace( '<table id="wp-calendar"' , '<table id="wp-calendar" class="table table-stripped"' , $markup ) ;
  return $markup;
}
add_filter( 'get_calendar' , 'bootBiz_calendar' ) ;


/*
 * bootBiz Original functions
 */
function bootBiz_wp_theme_text(){
  return "WordPress Theme <a href=".esc_url('http://marryandmerry.gift/wordpress-theme')." target='_blank'>bootBiz for Wedding</a>";
}
function bootBiz_pagination() {
  global $wp_query;
  $big = 12345678;
  $page_format = paginate_links( array(
      'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
      'format' => '?paged=%#%',
      'current' => max( 1, get_query_var('paged') ),
      'total' => $wp_query->max_num_pages,
      'type'  => 'array'
  ) );
  if( is_array($page_format) ) {
    $paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
    echo '<div class="text-center"><ul class="pagination">';
    echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
    foreach ( $page_format as $page ) {
    	echo "<li>$page</li>";
    }
    echo '</ul></div>';
    }
}


?>
